@@ -2,7 +2,7 @@ package App::Ack;
 
 use warnings;
 use strict;
-use File::Basename;
+use File::Basename ();
 
 =head1 NAME
 
@@ -10,11 +10,11 @@ App::Ack - A container for functions for the ack program
 
 =head1 VERSION
 
-Version 1.30
+Version 1.32
 
 =cut
 
-our $VERSION = '1.30';
+our $VERSION = '1.32';
 
 our %mappings = (
     asm         => [qw( s S )],
@@ -44,6 +44,8 @@ our %mappings = (
 
 =head1 SYNOPSIS
 
+If you want to know about the F<ack> program
+
 No user-serviceable parts inside.  F<ack> is all that should use this.
 
 =head1 FUNCTIONS
@@ -188,31 +190,32 @@ Default switches may be specified in ACK_SWITCHES environment variable.
 Example: ack -i select
 
 Searching:
-    -i              ignore case distinctions
-    -v              invert match: select non-matching lines
-    -w              force PATTERN to match only whole words
+    -i              Ignore case distinctions
+    -v              Invert match: select non-matching lines
+    -w              Force PATTERN to match only whole words
+    -Q              Quote all metacharacters; expr is literal
 
 Search output:
-    -l              only print filenames containing matches
-    -o              show only the part of a line matching PATTERN
+    -l              Only print filenames containing matches
+    -o              Show only the part of a line matching PATTERN
                     (turns off text highlighting)
-    --output=expr   output the evaluation of expr for each line
+    --output=expr   Output the evaluation of expr for each line
                     (turns off text highlighting)
-    -m=NUM          stop after NUM matches
-    -H              print the filename for each match
-    -h              suppress the prefixing filename on output
-    -c, --count     show number of lines matching per file
+    -m=NUM          Stop after NUM matches
+    -H              Print the filename for each match
+    -h              Suppress the prefixing filename on output
+    -c, --count     Show number of lines matching per file
 
-    --group         group matches by file name.
+    --group         Group matches by file name.
                     (default: on when used interactively)
     --nogroup       One result per line, including filename, like grep
                     (default: on when the output is redirected)
 
-    --[no]color     highlight the matching text (default: on unless
+    --[no]color     Highlight the matching text (default: on unless
                     output is redirected, or on Windows)
 
 File finding:
-    -f              only print the files found, without searching.
+    -f              Only print the files found, without searching.
                     The PATTERN must not be specified.
 
 File inclusion/exclusion:
@@ -222,11 +225,10 @@ File inclusion/exclusion:
 @LIST@
 
 Miscellaneous:
-    --help          this help
-    --version       display version
+    --help          This help
+    --version       Display version & copyright
     --thpppt        Bill the Cat
 
-
 GOTCHAS:
 Note that FILES must still match valid selection rules.  For example,
 
@@ -312,6 +314,21 @@ L<http://ack.googlecode.com/svn/>
 
 =head1 ACKNOWLEDGEMENTS
 
+Thanks to everyone who has contributed to ack in any way, including
+Rick Scott,
+Ask Bjørn Hanse,
+Jerry Gay,
+Will Coleda,
+Mike O'Regan,
+Slaven Rezic,
+Mark Stosberg,
+David Alan Pisoni,
+Adriano Ferreira,
+James Keenan,
+Leland Johnson,
+Ricardo Signes
+and Pete Krawczyk.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2005-2006 Andy Lester, all rights reserved.
